This folder contains small and/or artificial sample data or the actual
partner's data if really small. The production data to work with will most
likely live on an HPC system or some other external storage.
